"""File converters for the document library product"""

from os import listdir

def getFileConverters():
    """Import converter modules from this directory
       and return them as a dictionary keyed by content_type.

       Each converter module should define an attribute content_type and a function
       def convert(data) which should return text given data in the
       format the converter understands. content_type may be a string or a
       sequence of strings if several content_types are equivilant"""

    cvtr_dict = {}

    for cvtr_name in listdir(__path__[0]):
        if cvtr_name[0] != '_' and cvtr_name[-3:] == '.py':
            cvtr = __import__(cvtr_name[:-3], globals(), globals(), __path__)
            
            if hasattr(cvtr, 'content_type') and hasattr(cvtr, 'convert'):
                if type(cvtr.content_type) == type(''):
                    cvtr_dict[cvtr.content_type] = cvtr
                else:
                    for c_type in cvtr.content_type:
                        cvtr_dict[c_type] = cvtr
                
    return cvtr_dict

FileConverters = getFileConverters()
